// ignore_for_file: sized_box_for_whitespace

import 'package:flutter/material.dart';
import 'package:flutter_conditional_rendering/conditional.dart' as fcr;
import 'package:og1_post/og1_post.dart';
import 'package:og1_story/og1_story.dart';
import 'package:og1_system/og1_system.dart';

class Og1NewsFeed extends StatefulWidget {
  final UserModel currentUser;
  final List<UserModel> onlineUsers;
  final List<StoryModel> stories;
  final List<PostModel>? posts;

  const Og1NewsFeed(
      {Key? key,
      required this.currentUser,
      required this.onlineUsers,
      required this.stories,
      this.posts})
      : super(key: key);

  @override
  _Og1NewsFeedState createState() => _Og1NewsFeedState();
}

class _Og1NewsFeedState extends State<Og1NewsFeed> {
  @override
  Widget build(BuildContext context) {
    ScrollController _feedsScrollController = ScrollController();
    bool _notDesktop = !Responsive.isDesktop(context);

    return WillPopScope(
      onWillPop: () async {
        if (_feedsScrollController.offset > 0.0) {
          await _feedsScrollController.animateTo(
            0.0,
            duration: const Duration(milliseconds: 500),
            curve: Curves.easeInOut,
          );
          return false;
        } else {
          return true;
        }
      },
      child: SingleChildScrollView(
        key: const PageStorageKey('feeds'),
        controller: _feedsScrollController,
        scrollDirection: Axis.vertical,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            _notDesktop
                ? Og1NewPost(
                    currentUser: widget.currentUser,
                  )
                : Stories(
                    currentUser: widget.currentUser,
                    stories: widget.stories,
                  ),
            const SizedBox(height: 10.0),
            _notDesktop
                ? Stories(
                    currentUser: widget.currentUser,
                    stories: widget.stories,
                  )
                : Og1NewPost(
                    currentUser: widget.currentUser,
                  ),
            const SizedBox(height: 10.0),
            fcr.Conditional.single(
              context: context,
              conditionBuilder: (context) => widget.posts != null,
              widgetBuilder: (context) => ListView.separated(
                physics: const NeverScrollableScrollPhysics(),
                shrinkWrap: true,
                itemBuilder: (context, index) {
                  PostModel post = widget.posts![index];

                  return Og1Post(
                    post: post,
                  );
                },
                separatorBuilder: (context, index) {
                  return const SizedBox(height: 10.0);
                },
                itemCount: widget.posts!.length,
              ),
              fallbackBuilder: (context) => Container(
                height: 300.0,
                child: const Center(
                  child: CircularProgressIndicator(),
                ),
              ),
            ),
            if (widget.posts != null)
              const Padding(
                padding: EdgeInsets.symmetric(vertical: 2.5),
                child: Center(
                  child: Icon(
                    Icons.more_horiz_sharp,
                    color: Colors.black54,
                    size: 22.0,
                  ),
                ),
              ),
          ],
        ),
      ),
    );
  }
}
