import 'package:flutter/material.dart';
import 'package:og1_story/src/models/_models.dart';
import 'package:og1_story/src/widgets/_widgets.dart';
import 'package:og1_system/og1_system.dart';

class Stories extends StatelessWidget {
  final UserModel currentUser;
  final List<StoryModel> stories;

  const Stories({
    Key? key,
    required this.currentUser,
    required this.stories,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ResponsiveBuilder(builder: (context, sizingInformation) {
      EdgeInsets margin = const EdgeInsets.symmetric(horizontal: 0.0);
      double elevation = 0.0;
      ShapeBorder? shape;
      double height = 240.0;

      if (sizingInformation.deviceScreenType == DeviceScreenType.desktop) {
        margin = const EdgeInsets.symmetric(horizontal: 5.0);
        elevation = 1.0;
        shape =
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(10.0));
        height = 200.0;
      }
      return Card(
          margin: margin,
          elevation: elevation,
          shape: shape,
          child: Container(
            height: height,
            color: Theme.of(context).cardColor,
            child: ListView.builder(
              controller: ScrollController(),
              scrollDirection: Axis.horizontal,
              padding: const EdgeInsets.symmetric(
                vertical: 10.0,
                horizontal: 8.0,
              ),
              itemCount: 1 + stories.length,
              itemBuilder: (context, index) {
                if (index == 0) {
                  return Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 4.0),
                    child: StoryCard(
                      isAddStory: true,
                      currentUser: currentUser,
                    ),
                  );
                }

                final story = stories[index - 1];
                return Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 4.0),
                  child: StoryCard(story: story),
                );
              },
            ),
          ));
    });
  }
}
